﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
/**
 * \file SettingsMenu.cs
 * \brief Permet de manipuler le menu des paramètres.
 * 
 * \version 1.1
 * \author Thibault CLAUSS
 */

using UnityEngine.Audio;
using UnityEngine.UI;
using System.Linq;

public class SettingsMenu : MonoBehaviour
{
    /**Objet représentant l'audio du jeu.*/
    public AudioMixer audioMixer;
    /**ComboBox permettant la sélection de la résolutions du jeu.*/
    public Dropdown resolutionDropdown;

    /**Tableau des différentes résolutions accepté par le jeu.*/
    Resolution[] resolutions;

    /**
     * Méthode propre à Unity qui s'execute au lancement de l'objet utilisant ce script. \n
     * Ici elle est utilisé pour remplir la comboBox des résolutions.
     */
    public void Start()
    {
        resolutions = Screen.resolutions.Select(resolution => new Resolution { width = resolution.width, height = resolution.height }).Distinct().ToArray(); 
        resolutionDropdown.ClearOptions();

        List<string> options = new List<string>();

        int currentResolutionIndex = 0;
        for (int i = 0; i < resolutions.Length; i++)
        {
            string option = resolutions[i].width + "x" + resolutions[i].height;
            options.Add(option);

            if (resolutions[i].width == Screen.width && resolutions[i].height == Screen.height)
            {
                currentResolutionIndex = i;
            }
        }

        resolutionDropdown.AddOptions(options);
        resolutionDropdown.value = currentResolutionIndex;
        resolutionDropdown.RefreshShownValue();

        Screen.fullScreen = true;
    }

    /**
     * \fn public void SetVolume(float volume)
     * \brief Fonction permettant de modifier le volume du jeu.
     * 
     * \param volume : float représentant le nouveau volume audio du jeu.
     */
    public void SetVolume(float volume)
    {
        audioMixer.SetFloat("volume", volume);
    }

    public void SetMusic(float music)
    {
        audioMixer.SetFloat("music", music);
    }

    public void SetSound(float sound)
    {
        audioMixer.SetFloat("sound", sound);
    }

    /**
     * \fn public void SetFullScreen(bool isFullScreen)
     * \brief Fonction permettant de mettre le jeu en pleine écran ou non.
     * 
     * \param isFullScreen : bool représentant si le jeu doit être en pleine écran (true) ou non (false).
     */
    public void SetFullScreen(bool isFullScreen)
    {
        Screen.fullScreen = isFullScreen;
    }

    /**
     * \fn public void SetResolution(int resolutionIndex)
     * \brief Fonction permettant de changer la résolution du jeu.
     * 
     * \param resolutionIndex : int, index de de la comboBox que le joueur à sélectionné.
     */
    public void SetResolution(int resolutionIndex)
    {
        Resolution resolution = resolutions[resolutionIndex];
        Screen.SetResolution(resolution.width, resolution.height, Screen.fullScreen);
    }
}
